@@ -1,5 +1,5 @@
 
-from seti_python.class_read import ResponseReadCash, ResponseReadCashOut, ResponseReadPayment, ResponseReadTransactions
+from seti_python.class_read import ResponseReadCash, ResponseReadCashOut, ResponseReadPayment, ResponseReadTransactions, ResponseReadWallet, ResponseReadWalletsTransactions
 from seti_python.wallet_class import ResponseCreateWallet
 from seti_python.class_tools import BasicResponse, ResponseCreateTransaction
 from seti_python.payment_class import ResponseCreatePayment
@@ -143,7 +143,7 @@ class Seti():
          }
         READ_WALLET_URL = "read-wallet"
         encode_data = self.sign_data(data_read_wallet)
-        return ResponseCreateTransaction(self.send_request(data_read_wallet,encode_data,READ_WALLET_URL))
+        return ResponseReadWallet(self.send_request(data_read_wallet,encode_data,READ_WALLET_URL))
     
     def read_wallet_transactions(self,secret:str):
         self.is_error = False
@@ -152,7 +152,7 @@ class Seti():
          }
         READ_WALLET_TRANSACTIONS_URL = "read-wallet-transactions"
         encode_data = self.sign_data(data_read_wallet_transactions)
-        return ResponseCreateTransaction(self.send_request(data_read_wallet_transactions,encode_data,READ_WALLET_TRANSACTIONS_URL))
+        return ResponseReadWalletsTransactions(self.send_request(data_read_wallet_transactions,encode_data,READ_WALLET_TRANSACTIONS_URL))
     
     def send_money_between_wallets(self,from_secret:str,to_secret:str,value:int):
         self.is_error = False
