@@ -142,4 +142,47 @@ class ResponseReadTransactions(BasicResponse):
         self.msg=data['msg']
         self.res=data['res']
         self.data = ResponseReadTransactionsData(data['data'])
+   
+   
+# Read Wallet
+
+class WalletData:
+    balance:str
+    currency:str
+    locked:str
+    timestamp:str
+    wallet_id:int
+    def  __init__(self,data):
+        self.balance=data["balance"]
+        self.currency=data["currency"]
+        self.locked=data["locked"]
+        self.timestamp=data["timestamp"]
+        self.wallet_id =data["walletId"]
+  
+
+class ResponseReadWallet(BasicResponse):
+    data: WalletData
+    def __init__(self,data:dict):
+        self.msg=data['msg']
+        self.res=data['res']
+        self.data = WalletData(data['data'])
+   
+   
+   
+   
+# Read Wallet Movements
+
+  
+class ResponseReadWallesMovemtsData:
+    def __init__(self,data:dict):
+        self.input = list(map(Transaction,data['input']))
+        self.output =  list(map(Transaction,data['output']))
+        
+class ResponseReadWalletsTransactions(BasicResponse):
+    data: ResponseReadWallesMovemtsData
+    def __init__(self,data:dict):
+        self.msg=data['msg']
+        self.res=data['res']
+        self.data = ResponseReadWallesMovemtsData(data['data'])
+   
    
\ No newline at end of file
